@@ -7,12 +7,16 @@ from tests.test_models import suite as models_suite
 from tests.test_xml_wrappers import suite as xml_suite
 from tests.test_station import suite as station_suite
 from tests.test_cartography import suite as cartography_suite
+from tests.test_status import suite as status_suite
+from tests.test_geofinder import suite as geofinder_suite
 
 db_connection('sqlite:///:memory:')
 
 global_test_suite = unittest.TestSuite([models_suite,
                                         xml_suite,
                                         station_suite,
-                                        cartography_suite,])
+                                        cartography_suite,
+                                        status_suite,
+                                        geofinder_suite,])
 
 
