@@ -2,7 +2,7 @@
 from urllib import urlopen
 from xml.dom.minidom import parse
 
-from veliberator.settings import VELIB_DATA_XML_URL
+from veliberator.settings import XML_URL_DATA_STATION
 from veliberator.xml_wrappers import xml_station_information_wrapper
 from veliberator.models import StationInformation, session
 
@@ -11,7 +11,7 @@ class Cartography(object):
     """Grab the data and save it in db"""
 
     @staticmethod
-    def synchronize(url=VELIB_DATA_XML_URL):
+    def synchronize(url=XML_URL_DATA_STATION):
         dom = parse(urlopen(url))
         for marker in dom.getElementsByTagName('marker'):
             values = xml_station_information_wrapper(marker)
