@@ -4,8 +4,8 @@ from ConfigParser import SafeConfigParser
 from ConfigParser import NoSectionError, NoOptionError
 
 config = SafeConfigParser()
-config.read([os.path.join('etc', 'veliberator.cfg'),
-             os.path.expanduser('~/.veliberator.cfg'),
+config.read([os.path.expanduser('~/.veliberator.cfg'),
+             os.path.join('etc', 'veliberator.cfg'),
              os.path.join('/etc', 'veliberator.cfg'),])
 
 XML_URL_DATA_STATION = config.get('XML', 'url_data_station')
